import os
import asciianim as b
b.clear()
a = [['1','2',' '],[' ','4','5'],['6',' ',' ']]
os.system("")
run = False
string = ""
for i in range(len(a)):
    text=""
    if(i!=0):
        text+="\n"
    for j in range(len(a[0])):
        if(a[i][j]!=' '):
            run = True
        else:
            run = False
        if(run):
            x=i+1
            y=j+1
            text += "\x1b7\x1b["+str(x)+";"+str(y)+"f"+a[i][j]+"\x1b8"
    
    string+=text
string = string.strip()
print(string)
input()




import asciianim as a
a.createcanvas(100,100,True)
p1 = a.vector3d(10,10,1)
p2 = a.vector3d(80,80,1)
p3 = a.vector3d(80,10,1)
tri = a.triangle(p1,p2,p3)
centroid = a.vector3d(round((p1.x+p2.x+p3.x)/3),round((p1.y+p2.y+p3.y)/3),round((p1.z+p2.z+p3.z)/3))
a.fillmesh(tri,centroid,[10,10],10,True)
input()



import asciianim as a
a.createcanvas()
obj = a.import_obj("VideoShip.obj")
while True:
    p = obj.p
    a.rza(0.03,p)
    obj.p = p
    a.Draw_Object(obj,2,True,False)
    a.draw()
    a.clearbg()

input()


    
